
#ifndef _C1_uc38_
#define _C1_uc38_

#ifdef __cplusplus
extern "C" {
#endif

RTOSHF (EIF_CHARACTER_32,757)
static EIF_CHARACTER_32 F65_757_body(EIF_REFERENCE);
extern EIF_CHARACTER_32 F65_757(EIF_REFERENCE);
extern void EIF_Minit38(void);

#ifdef __cplusplus
}
#endif

#endif
